//  Copyright (c) 2007-2014 Hartmut Kaiser
//  Copyright (c) 2014 Grant Mercer
//
//  SPDX-License-Identifier: BSL-1.0
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

#pragma once

#include <hpx/config.hpp>
#include <hpx/parallel/algorithms/fill.hpp>
#include <hpx/parallel/container_algorithms/fill.hpp>

#include <hpx/parallel/segmented_algorithms/fill.hpp>
